@@ -32,6 +32,13 @@ setMethod("ros", signature(obs="numeric", censored="logical"),
         warning("Input > 80% censored -- Results are tenuous.\n")
     }
 
+    ix = obs[censored][which(obs[censored] > max(obs[!censored]))]
+    if (length(ix)) {
+      warning("Dropped censored values that exceed max of uncensored values.")
+      obs = obs[obs < min(ix)]
+      censored = censored[obs < min(ix)]
+    } 
+
     ix = order(obs)
     obs = obs[ix]
     censored = censored[ix]
